@@ -82,9 +82,6 @@ namespace xt
         using stepper = typename iterable_base::stepper;
         using const_stepper = typename iterable_base::const_stepper;
 
-        static constexpr layout_type static_layout = layout_type::dynamic;
-        static constexpr bool contiguous_layout = false;
-
         template <class S = shape_type>
         void resize(const S& shape);
         template <class S = shape_type>
@@ -226,8 +223,7 @@ namespace xt
         bool check_array(const pybind11::handle& src)
         {
             using is_arithmetic_type = std::integral_constant<bool, bool(pybind11::detail::satisfies_any_of<T, std::is_arithmetic, xtl::is_complex>::value)>;
-            return PyArray_Check(src.ptr()) &&
-                   check_array_type<T>(src, is_arithmetic_type{});
+            return PyArray_Check(src.ptr()) && check_array_type<T>(src, is_arithmetic_type{});
         }
     }
 
@@ -277,9 +273,7 @@ namespace xt
     template <class D>
     inline bool pycontainer<D>::check_(pybind11::handle h)
     {
-        auto dtype = pybind11::detail::npy_format_descriptor<value_type>::dtype();
-        return PyArray_Check(h.ptr()) &&
-            PyArray_EquivTypes_(PyArray_TYPE(reinterpret_cast<PyArrayObject*>(h.ptr())), dtype.ptr());
+        return detail::check_array<typename D::value_type>(h);
     }
 
     template <class D>
@@ -321,6 +315,30 @@ namespace xt
         return *static_cast<const derived_type*>(this);
     }
 
+    namespace detail
+    {
+        template <class S>
+        struct check_dims
+        {
+            static bool run(std::size_t)
+            {
+                return true;
+            }
+        };
+
+        template <class T, std::size_t N>
+        struct check_dims<std::array<T, N>>
+        {
+            static bool run(std::size_t new_dim)
+            {
+                if(new_dim != N)
+                {
+                    throw std::runtime_error("Dims not matching.");
+                }
+                return new_dim == N;
+            }
+        };
+    }
 
     /**
      * resizes the container.
@@ -359,6 +377,7 @@ namespace xt
     template <class S>
     inline void pycontainer<D>::resize(const S& shape, const strides_type& strides)
     {
+        detail::check_dims<shape_type>::run(shape.size());
         derived_type tmp(xtl::forward_sequence<shape_type>(shape), strides);
         *static_cast<derived_type*>(this) = std::move(tmp);
     }
@@ -369,9 +388,9 @@ namespace xt
     {
         if (compute_size(shape) != this->size())
         {
-            throw std::runtime_error("Cannot reshape with incorrect number of elements.");
+            throw std::runtime_error("Cannot reshape with incorrect number of elements (" + std::to_string(this->size()) + " vs " + std::to_string(compute_size(shape)) + ")");
         }
-
+        detail::check_dims<shape_type>::run(shape.size());
         layout = default_assignable_layout(layout);
 
         NPY_ORDER npy_layout;
@@ -388,7 +407,8 @@ namespace xt
             throw std::runtime_error("Cannot reshape with unknown layout_type.");
         }
 
-        PyArray_Dims dims = {reinterpret_cast<npy_intp*>(shape.data()), static_cast<int>(shape.size())};
+        using shape_ptr = typename std::decay_t<S>::pointer;
+        PyArray_Dims dims = {reinterpret_cast<npy_intp*>(const_cast<shape_ptr>(shape.data())), static_cast<int>(shape.size())};
         auto new_ptr = PyArray_Newshape((PyArrayObject*) this->ptr(), &dims, npy_layout);
         auto old_ptr = this->ptr();
         this->ptr() = new_ptr;
